print("import: 'gwpy'")
import gwpy

print("import: 'gwpy.astro'")
import gwpy.astro

print("import: 'gwpy.cli'")
import gwpy.cli

print("import: 'gwpy.detector'")
import gwpy.detector

print("import: 'gwpy.frequencyseries'")
import gwpy.frequencyseries

print("import: 'gwpy.io'")
import gwpy.io

print("import: 'gwpy.plot'")
import gwpy.plot

print("import: 'gwpy.segments'")
import gwpy.segments

print("import: 'gwpy.signal'")
import gwpy.signal

print("import: 'gwpy.spectrogram'")
import gwpy.spectrogram

print("import: 'gwpy.table'")
import gwpy.table

print("import: 'gwpy.testing'")
import gwpy.testing

print("import: 'gwpy.time'")
import gwpy.time

print("import: 'gwpy.timeseries'")
import gwpy.timeseries

print("import: 'gwpy.types'")
import gwpy.types

print("import: 'gwpy.utils'")
import gwpy.utils

